<?php

namespace Drupal\cck_select_other\Tests;

/**
 * Assert that a default value is selected.
 *
 * @group cck_select_other
 */
class CCKSelectOtherDefaultValueTest extends CCKSelectOtherTestBase {
  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->list_options = $this->createOptions();
    list($this->default_value, $label) = $this->getRandomOption($this->list_options);

    $field_info = array(
      'settings' => array(
        'allowed_values' => $this->list_options,
      ),
      'cardinality' => 1,
    );
    $instance_info = array(
      'required' => 0,
      'default_value' => array(
        array('value' => $this->default_value),
      ),
    );

    $this->field = $this->createSelectOtherListField('list_string', $field_info, $instance_info);
    $this->assertEqual(count($this->field->getSetting('allowed_values')), 5, 'Found 5 allowed values.');

    $this->field_name = $this->field->getName();
  }

  /**
   * Test field validation for required attribute.
   */
  public function testRequired() {
    // Login as content creator.
    $this->drupalLogin($this->web_user);

    $field_id = 'edit-' . $this->field_name . '-0-select-other-list';
    $this->drupalGet('node/add/' . $this->contentType->id());
    $this->assertOptionSelected($field_id, $this->default_value, t('Default value selected is %value', array('%value' => $this->default_value)));
  }
}
