<?php

namespace Drupal\cck_select_other\Tests;

/**
 * Assert list_integer field values saved correctly.
 *
 * @group cck_select_other
 */
class CCKSelectOtherIntegerFieldTest extends CCKSelectOtherTestBase {
  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->list_options = $this->createOptions();

    $field_info = array(
      'settings' => array(
        'allowed_values' => $this->list_options,
      ),
      'cardinality' => 1,
    );
    $instance_info = array(
      'required' => 0,
    );

    $this->field = $this->createSelectOtherListField('list_integer', $field_info, $instance_info);
    $this->assertEqual(count($this->field->getSetting('allowed_values')), 5, 'Found 5 allowed values.');

    $this->field_name = $this->field->getName();
  }

  /**
   * {@inheritdoc}
   */
  public function createOptions($num = 5) {
    $options = array();
    for ($i = 0; $i < $num; $i++) {
      $options[$i] = $i;
    }
    return $options;
  }

  /**
   * Assert saving an allowed value and an other value.
   */
  public function testSelectOtherList() {
    // Login as content creator.
    $this->drupalLogin($this->web_user);

    // Create a new node with other value.
    $edit = array(
      'title[0][value]' => $this->randomString(25),
      $this->field_name . '[0][select_other_list]' => 'other',
      $this->field_name . '[0][select_other_text_input]' => 10,
    );
    $this->drupalPostForm('node/add/' . $this->contentType->id(), $edit, t('Save'));
    $this->assertRaw('<div class="field__item">10</div>', 'Successfully saved other integer value.');

    // Edit node with other value to list value.
    list($new_value, $new_label) = $this->getRandomOption($this->list_options);
    $edit = array(
      $this->field_name . '[0][select_other_list]' => $new_value,
      $this->field_name . '[0][select_other_text_input]' => '',
    );
    $this->drupalPostForm('node/1/edit', $edit, t('Save'));
    $this->assertRaw('<div class="field__item">' . $new_label . '</div>', t('Successfully saved list value to existing node, %value', array('%value' => $new_value)));

    // Create a new node with list value
    $edit = array(
      $this->field_name . '[0][select_other_list]' => 'other',
      $this->field_name . '[0][select_other_text_input]' => $this->randomString(10),
    );
    $this->drupalPostForm('node/add/' . $this->contentType->id(), $edit, t('Save'));
    $elements = $this->xpath('//input[@name="' . $this->field_name .'[0][select_other_text_input]" and contains(@class, "error")]');
    $this->assertEqual(count($elements), 1, 'Returned error on node save for invalid integer.');
  }
}
