<?php

namespace Drupal\cck_select_other\Tests;

/**
 * Assert that two select other fields work on the same node.
 *
 * @group cck_select_other
 */
class CCKSelectOtherMultipleFieldTest extends CCKSelectOtherTestBase {
  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    // Create the first field.
    $this->field_one_options = $this->createOptions();

    $field_info = array(
      'settings' => array(
        'allowed_values' => $this->field_one_options,
      ),
      'cardinality' => 1,
    );
    $instance_info = array(
      'required' => 0,
    );

    $this->field_one = $this->createSelectOtherListField('list_string', $field_info, $instance_info);
    $this->assertEqual(count($this->field_one->getSetting('allowed_values')), 5, 'Found 5 allowed values.');
    $this->field_one_name = $this->field_one->getName();

    // Create the second field.
    $this->field_two_options = $this->createOptions();

    $field_info = array(
      'settings' => array(
        'allowed_values' => $this->field_two_options,
      ),
      'cardinality' => 1,
    );
    $instance_info = array(
      'required' => 0,
    );

    $this->field_two = $this->createSelectOtherListField('list_string', $field_info, $instance_info);
    $this->assertEqual(count($this->field_two->getSetting('allowed_values')), 5, 'Found 5 allowed values.');
    $this->field_two_name = $this->field_two->getName();
  }

  /**
   * Test that field one and field two have unique values.
   */
  public function testMultipleFields() {
    // Login as content creator.
    $this->drupalLogin($this->web_user);

    list($value_one, $label) = $this->getRandomOption($this->field_one_options);
    $value_two = $this->getRandomGenerator()->word(15);

    $edit = array(
      'title[0][value]' => $this->randomString(25),
      $this->field_one_name . '[0][select_other_list]' => $value_one,
      $this->field_two_name . '[0][select_other_list]' => 'other',
      $this->field_two_name . '[0][select_other_text_input]' => $value_two,
    );
    $this->drupalPostForm('node/add/' . $this->contentType->id(), $edit, t('Save'));
    $this->assertRaw('<div class="field__item">' . $this->field_one_options[$value_one] . '</div>', t('Successfully saved list value, %value', array('%value' => $value_one )));
    $this->assertRaw('<div class="field__item">' . $value_two . '</div>', t('Successfully saved list value, %value', array('%value' => $value_two)));
  }
}
