<?php

namespace Drupal\cck_select_other\Tests;

/**
 * Assert that multiple values are saved properly.
 *
 * @group cck_select_other
 */
class CCKSelectOtherMultipleValueTest extends CCKSelectOtherTestBase {
  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->list_options = $this->createOptions();

    $field_info = array(
      'settings' => array(
        'allowed_values' => $this->list_options,
      ),
      'cardinality' => 3,
    );
    $instance_info = array(
      'required' => 0,
    );

    $this->field = $this->createSelectOtherListField('list_string', $field_info, $instance_info);
    $this->assertEqual(count($this->field->getSetting('allowed_values')), 5, 'Found 5 allowed values.');

    $this->field_name = $this->field->getName();
  }

  /**
   * Test field validation for required attribute.
   */
  public function testMutipleValues() {
    // Login as content creator.
    $this->drupalLogin($this->web_user);

    list($value, $label) = $this->getRandomOption($this->list_options);
    $other_value = $this->getRandomGenerator()->word(15);
    $third_value = $this->getRandomGenerator()->word(5);

    $edit = array(
      'title[0][value]' => $this->randomString(25),
      $this->field_name . '[0][select_other_list]' => 'other',
      $this->field_name . '[0][select_other_text_input]' => $other_value,
      $this->field_name . '[1][select_other_list]' => $value,
      $this->field_name . '[1][select_other_text_input]' => '',
      $this->field_name . '[2][select_other_list]' => 'other',
      $this->field_name . '[2][select_other_text_input]' => $third_value,
    );
    $this->drupalPostForm('node/add/' . $this->contentType->id(), $edit, t('Save'));
    $this->assertRaw('<div class="field__item">' . $this->list_options[$value] . '</div>', t('Successfully saved list value, %value', array('%value' => $value)));
    $this->assertRaw('<div class="field__item">' . $other_value . '</div>', t('Successfully saved list value, %value', array('%value' => $other_value)));
    $this->assertRaw('<div class="field__item">' . $third_value . '</div>', t('Successfully saved list value, %value', array('%value' => $third_value)));

    $this->drupalGet('node/1/edit');
    $this->assertOptionSelected('edit-' . $this->field_name . '-0-select-other-list', 'other', 'Select list #0 other selected');
    $this->assertOptionSelected('edit-' . $this->field_name . '-1-select-other-list', $value, 'Select list #1 other selected');
    $this->assertOptionSelected('edit-' . $this->field_name . '-2-select-other-list', 'other', 'Select list #2 other selected');

    $edit = array(
      $this->field_name . '[2][select_other_list]' => '_none',
      $this->field_name . '[2][select_other_text_input]' => '',
    );
    $this->drupalPostForm('node/1/edit', $edit, t('Save'));

    // List fields re-arrange themselves in alphabetical order, and so it is not
    // possible to assert the exact value because Drupal. Instead there should
    // only be 2 field items listed.
    $elements = $this->xpath('//div[contains(@class, "field--name-' . $this->field_name . '")]/div[@class="field__items"]/div[@class="field__item"]');
    $this->assertEqual(2, count($elements), 'Found only two field items.');
  }
}
