<?php

namespace Drupal\cck_select_other\Tests;

/**
 * Assert that required fields work correctly.
 *
 * @group cck_select_other
 */
class CCKSelectOtherRequiredTest extends CCKSelectOtherTestBase {
  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->list_options = $this->createOptions();

    $field_info = array(
      'settings' => array(
        'allowed_values' => $this->list_options,
      ),
      'cardinality' => 1,
    );
    $instance_info = array(
      'required' => 1,
    );

    $this->field = $this->createSelectOtherListField('list_string', $field_info, $instance_info);
    $this->assertEqual(count($this->field->getSetting('allowed_values')), 5, 'Found 5 allowed values.');

    $this->field_name = $this->field->getName();
  }

  /**
   * Test field validation for required attribute.
   */
  public function testRequired() {
    // Login as content creator.
    $this->drupalLogin($this->web_user);

    $edit = array(
      'title[0][value]' => $this->randomString(25),
      $this->field_name . '[0][select_other_list]' => 'other',
      $this->field_name . '[0][select_other_text_input]' => '',
    );
    $this->drupalPostForm('node/add/' . $this->contentType->id(), $edit, t('Save'));
    $this->assertRaw(t('You must provide a value for this option.'), 'Failed validation for required field.');
    $elements = $this->xpath('//input[@name="' . $this->field_name .'[0][select_other_text_input]" and contains(@class, "error")]');
    $this->assertEqual(count($elements), 1, 'Found 1 error class on select other list text input');

    // Successfully post the form.
    $value = $this->getRandomGenerator()->word(25);
    $edit[$this->field_name . '[0][select_other_text_input]'] = $value;
    $this->drupalPostForm(NULL, $edit, t('Save'));
    $this->assertText($value, 'Found select list other value after node save.');
  }
}
