<?php

namespace Drupal\cck_select_other\Tests;

/**
 * Assert field values saved correctly for list text fields.
 *
 * @group cck_select_other
 */
class CCKSelectOtherTextFieldTest extends CCKSelectOtherTestBase {
  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->list_options = $this->createOptions();

    $field_info = array(
      'settings' => array(
        'allowed_values' => $this->list_options,
      ),
      'cardinality' => 1,
    );
    $instance_info = array(
      'required' => 0,
    );

    $this->field = $this->createSelectOtherListField('list_string', $field_info, $instance_info);
    $this->assertEqual(count($this->field->getSetting('allowed_values')), 5, 'Found 5 allowed values.');

    $this->field_name = $this->field->getName();
  }

  /**
   * Assert saving an allowed value and an other value.
   */
  public function testSelectOtherList() {
    // Login as content creator.
    $this->drupalLogin($this->web_user);

    // Create a new node with other value.
    $value = $this->getRandomGenerator()->word(10);
    $edit = array(
      'title[0][value]' => $this->randomString(25),
      $this->field_name . '[0][select_other_list]' => 'other',
      $this->field_name . '[0][select_other_text_input]' => $value,
    );
    $this->drupalPostForm('node/add/' . $this->contentType->id(), $edit, t('Save'));
    $this->assertRaw('<div class="field__item">' . $value . '</div>', t('Successfully saved other value, %value', array('%value' => $value)));

    // Edit node with other value to list value.
    list($new_value, $new_label) = $this->getRandomOption($this->list_options);
    $edit = array(
      $this->field_name . '[0][select_other_list]' => $new_value,
      $this->field_name . '[0][select_other_text_input]' => '',
    );
    $this->drupalPostForm('node/1/edit', $edit, t('Save'));
    $this->assertRaw('<div class="field__item">' . $new_label . '</div>', t('Successfully saved list value to existing node, %value', array('%value' => $new_value)));

    // Create a new node with list value
    $edit = array(
      'title[0][value]' => $this->randomString(25),
      $this->field_name . '[0][select_other_list]' => $new_value,
      $this->field_name . '[0][select_other_text_input]' => '',
    );
    $this->drupalPostForm('node/add/' . $this->contentType->id(), $edit, t('Save'));
    $this->assertRaw('<div class="field__item">' . $this->list_options[$new_value] . '</div>', t('Successfully saved list value, %value', array('%value' => $new_value)));

    // Edit node with list value to other value.
    $value = $this->getRandomGenerator()->word(10);
    $edit = array(
      $this->field_name . '[0][select_other_list]' => 'other',
      $this->field_name . '[0][select_other_text_input]' => $value,
    );
    $this->drupalPostForm('node/2/edit', $edit, t('Save'));
    $this->assertRaw('<div class="field__item">' . $value . '</div>', t('Successfully saved other value to existing node, %value', array('%value' => $value)));
  }
}
